<p align="center">
<img src="https://raw.githubusercontent.com/wiki/cybiere/baboossh/img/logo.png" /><br />
SSH spreading made easy for red teams in a hurry.
</p>


BabooSSH allows you, from a simple SSH connection to a compromised host, to quickly gather info on other SSH endpoints to pivot and compromise them.

# Licence

BabooSSH is developped by [Akerva](https://akerva.com/) and provided for free under the GNU/GPLv3.

# Install and documentation

Have a look on the [wiki](https://github.com/cybiere/BabooSSH/wiki).


